#[non_exhaustive]pub enum DecodeAuthorizationMessageError {
InvalidAuthorizationMessageException(InvalidAuthorizationMessageException),
Unhandled(Unhandled),
}Expand description
Error type for the DecodeAuthorizationMessageError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidAuthorizationMessageException(InvalidAuthorizationMessageException)
The error returned if the message passed to DecodeAuthorizationMessage was invalid. This can happen if the token contains invalid characters, such as line breaks, or if the message has expired.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DecodeAuthorizationMessageError
impl DecodeAuthorizationMessageError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DecodeAuthorizationMessageError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DecodeAuthorizationMessageError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Returns true if the error kind is DecodeAuthorizationMessageError::InvalidAuthorizationMessageException.