pub struct GetDelegatedAccessTokenFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetDelegatedAccessToken.
Exchanges a trade-in token for temporary Amazon Web Services credentials with the permissions associated with the assumed principal. This operation allows you to obtain credentials for a specific principal based on a trade-in token, enabling delegation of access to Amazon Web Services resources.
Implementations
Sourceimpl GetDelegatedAccessTokenFluentBuilder
impl GetDelegatedAccessTokenFluentBuilder
Sourcepub fn as_input(&self) -> &GetDelegatedAccessTokenInputBuilder
pub fn as_input(&self) -> &GetDelegatedAccessTokenInputBuilder
Access the GetDelegatedAccessToken as a reference.
Sourcepub async fn send(
self,
) -> Result<GetDelegatedAccessTokenOutput, SdkError<GetDelegatedAccessTokenError, HttpResponse>>
pub async fn send( self, ) -> Result<GetDelegatedAccessTokenOutput, SdkError<GetDelegatedAccessTokenError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetDelegatedAccessTokenOutput, GetDelegatedAccessTokenError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetDelegatedAccessTokenOutput, GetDelegatedAccessTokenError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn trade_in_token(self, input: impl Into<String>) -> Self
pub fn trade_in_token(self, input: impl Into<String>) -> Self
The token to exchange for temporary Amazon Web Services credentials. This token must be valid and unexpired at the time of the request.
Sourcepub fn set_trade_in_token(self, input: Option<String>) -> Self
pub fn set_trade_in_token(self, input: Option<String>) -> Self
The token to exchange for temporary Amazon Web Services credentials. This token must be valid and unexpired at the time of the request.
Sourcepub fn get_trade_in_token(&self) -> &Option<String>
pub fn get_trade_in_token(&self) -> &Option<String>
The token to exchange for temporary Amazon Web Services credentials. This token must be valid and unexpired at the time of the request.