#[non_exhaustive]pub struct GetDelegatedAccessTokenOutputBuilder { /* private fields */ }Expand description
A builder for GetDelegatedAccessTokenOutput.
Implementations
Sourceimpl GetDelegatedAccessTokenOutputBuilder
impl GetDelegatedAccessTokenOutputBuilder
Sourcepub fn credentials(self, input: Credentials) -> Self
pub fn credentials(self, input: Credentials) -> Self
Amazon Web Services credentials for API authentication.
Sourcepub fn set_credentials(self, input: Option<Credentials>) -> Self
pub fn set_credentials(self, input: Option<Credentials>) -> Self
Amazon Web Services credentials for API authentication.
Sourcepub fn get_credentials(&self) -> &Option<Credentials>
pub fn get_credentials(&self) -> &Option<Credentials>
Amazon Web Services credentials for API authentication.
Sourcepub fn packed_policy_size(self, input: i32) -> Self
pub fn packed_policy_size(self, input: i32) -> Self
The percentage of the maximum policy size that is used by the session policy. The policy size is calculated as the sum of all the session policies and permission boundaries attached to the session. If the packed size exceeds 100%, the request fails.
Sourcepub fn set_packed_policy_size(self, input: Option<i32>) -> Self
pub fn set_packed_policy_size(self, input: Option<i32>) -> Self
The percentage of the maximum policy size that is used by the session policy. The policy size is calculated as the sum of all the session policies and permission boundaries attached to the session. If the packed size exceeds 100%, the request fails.
Sourcepub fn get_packed_policy_size(&self) -> &Option<i32>
pub fn get_packed_policy_size(&self) -> &Option<i32>
The percentage of the maximum policy size that is used by the session policy. The policy size is calculated as the sum of all the session policies and permission boundaries attached to the session. If the packed size exceeds 100%, the request fails.
Sourcepub fn assumed_principal(self, input: impl Into<String>) -> Self
pub fn assumed_principal(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the principal that was assumed when obtaining the delegated access token. This ARN identifies the IAM entity whose permissions are granted by the temporary credentials.
Sourcepub fn set_assumed_principal(self, input: Option<String>) -> Self
pub fn set_assumed_principal(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the principal that was assumed when obtaining the delegated access token. This ARN identifies the IAM entity whose permissions are granted by the temporary credentials.
Sourcepub fn get_assumed_principal(&self) -> &Option<String>
pub fn get_assumed_principal(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the principal that was assumed when obtaining the delegated access token. This ARN identifies the IAM entity whose permissions are granted by the temporary credentials.
Sourcepub fn build(self) -> GetDelegatedAccessTokenOutput
pub fn build(self) -> GetDelegatedAccessTokenOutput
Consumes the builder and constructs a GetDelegatedAccessTokenOutput.