#[non_exhaustive]pub struct GetFederationTokenOutput {
pub credentials: Option<Credentials>,
pub federated_user: Option<FederatedUser>,
pub packed_policy_size: Option<i32>,
pub session_token_utilization: Option<i32>,
pub session_token_size: Option<i32>,
/* private fields */
}Expand description
Contains the response to a successful GetFederationToken request, including temporary Amazon Web Services credentials that can be used to make Amazon Web Services requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.credentials: Option<Credentials>The temporary security credentials, which include an access key ID, a secret access key, and a security (or session) token.
The size of the security token that STS API operations return is not fixed. We strongly recommend that you make no assumptions about the maximum size.
federated_user: Option<FederatedUser>Identifiers for the federated user associated with the credentials (such as arn:aws:sts::123456789012:federated-user/Bob or 123456789012:Bob). You can use the federated user's ARN in your resource-based policies, such as an Amazon S3 bucket policy.
packed_policy_size: Option<i32>Deprecated. Replaced by SessionTokenUtilization.
A percentage value that indicates the packed size of the session policies and session tags combined passed in the request. The request fails if the packed size is greater than 100 percent, which means the policies and tags exceeded the allowed space.
session_token_utilization: Option<i32>The percentage (0-100) of the maximum allowed session token size that the returned session token consumes.
session_token_size: Option<i32>The size, in bytes, of the session token returned in the Credentials for this response.
Implementations
Sourceimpl GetFederationTokenOutput
impl GetFederationTokenOutput
Sourcepub fn credentials(&self) -> Option<&Credentials>
pub fn credentials(&self) -> Option<&Credentials>
The temporary security credentials, which include an access key ID, a secret access key, and a security (or session) token.
The size of the security token that STS API operations return is not fixed. We strongly recommend that you make no assumptions about the maximum size.
Sourcepub fn federated_user(&self) -> Option<&FederatedUser>
pub fn federated_user(&self) -> Option<&FederatedUser>
Identifiers for the federated user associated with the credentials (such as arn:aws:sts::123456789012:federated-user/Bob or 123456789012:Bob). You can use the federated user's ARN in your resource-based policies, such as an Amazon S3 bucket policy.
Sourcepub fn packed_policy_size(&self) -> Option<i32>
👎Deprecated since 2026-06-17: Deprecated. Replaced by SessionTokenUtilization.
pub fn packed_policy_size(&self) -> Option<i32>
Deprecated. Replaced by SessionTokenUtilization.
A percentage value that indicates the packed size of the session policies and session tags combined passed in the request. The request fails if the packed size is greater than 100 percent, which means the policies and tags exceeded the allowed space.
Sourcepub fn session_token_utilization(&self) -> Option<i32>
pub fn session_token_utilization(&self) -> Option<i32>
The percentage (0-100) of the maximum allowed session token size that the returned session token consumes.
Sourcepub fn session_token_size(&self) -> Option<i32>
pub fn session_token_size(&self) -> Option<i32>
The size, in bytes, of the session token returned in the Credentials for this response.
Sourceimpl GetFederationTokenOutput
impl GetFederationTokenOutput
Sourcepub fn builder() -> GetFederationTokenOutputBuilder
pub fn builder() -> GetFederationTokenOutputBuilder
Creates a new builder-style object to manufacture GetFederationTokenOutput.